@@ -85,6 +85,16 @@ class Utilities:
 		The default state after initializing the session is ON."""
 		self._core.io.query_instr_status = value
 
+	@property
+	def encoding(self) -> str:
+		"""Returns string<=>bytes encoding of the session."""
+		return self._core.io.encoding
+
+	@encoding.setter
+	def encoding(self, value: str) -> None:
+		"""Sets string<=>bytes encoding of the session."""
+		self._core.io.encoding = value
+
 	@property
 	def opc_query_after_write(self) -> bool:
 		"""Sets / returns Instrument *OPC? query sending after each command write.
@@ -145,11 +155,15 @@ class Utilities:
 	def reset(self) -> None:
 		"""SCPI command: *RST
 		Sends *RST command + calls the clear_status()."""
-		return self._core.io.reset()
+		self._core.io.reset()
+		self.default_instrument_setup()
+
+	def default_instrument_setup(self) -> None:
+		"""Custom steps performed at the init and at the reset()."""
 
 	def self_test(self, timeout: int = None) -> Tuple[int, str]:
 		"""SCPI command: *TST?
-		Performs instrument's selftest.
+		Performs instrument's self-test.
 		Returns tuple (code:int, message: str). Code 0 means the self-test passed.
 		You can define the custom timeout in milliseconds. If you do not define it, the default selftest timeout is used (usually 60 secs)."""
 		return self._core.io.self_test(timeout)
