@@ -11,11 +11,11 @@ class Apply:
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("apply", core, parent)
+		self._cmd_group = CommandsGroup("apply", core, parent)
 
-	def set(self, voltage: float, current: float = None, output: int = None) -> None:
+	def set(self, voltage: float, current: float, output: bool) -> None:
 		"""SCPI: APPLy \n
-		Snippet: driver.apply.set(voltage = 1.0, current = 1.0, output = 1) \n
+		Snippet: driver.apply.set(voltage = 1.0, current = 1.0, output = False) \n
 		Sets or queries the voltage and current value of the selected channel. \n
 			:param voltage:
 				- numeric: Numeric value for voltage in the range of 0.000 to 64.050.
@@ -32,5 +32,5 @@ class Apply:
 				- OUT2 | OUTP2 | OUTPut2 | CH2: Selects output for channel 2.
 				- OUT3 | OUTP3 | OUTPut3 | CH3: Selects output for channel 2.
 				- OUT4 | OUTP4 | OUTPut4 | CH4: Selects output for channel 4."""
-		param = ArgSingleList().compose_cmd_string(ArgSingle('voltage', voltage, DataType.Float), ArgSingle('current', current, DataType.Float, True), ArgSingle('output', output, DataType.Integer, True))
-		self._core.io.write(f'APPLy {param}'.rstrip())
+		param = ArgSingleList().compose_cmd_string(ArgSingle('voltage', voltage, DataType.Float), ArgSingle('current', current, DataType.Float), ArgSingle('output', output, DataType.Boolean))
+		self._core.io.write_with_opc(f'APPLy {param}'.rstrip())
