@@ -11,7 +11,7 @@ from .Internal.ArgStruct import ArgStruct
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class RsNgx:
 	"""289 total commands, 21 Sub-groups, 1 group commands"""
-	_driver_options = "SupportedInstrModels = NGP/NGL/NGM/NGU, SupportedIdnPatterns = NGP/NGL/NGM/NGU, SimulationIdnString = 'Rohde&Schwarz,NGP,100001,3.1.0.0048'"
+	_driver_options = "SupportedInstrModels = NGP/NGL/NGM/NGU, SupportedIdnPatterns = NGP/NGL/NGM/NGU, SimulationIdnString = 'Rohde&Schwarz,NGP,100001,3.1.0.0049'"
 
 	def __init__(self, resource_name: str, id_query: bool = True, reset: bool = False, options: str = None, direct_session: object = None):
 		"""Initializes new RsNgx session. \n
@@ -40,12 +40,13 @@ class RsNgx:
 		:param options: string tokens alternating the driver settings.
 		:param direct_session: Another driver object or pyVisa object to reuse the session instead of opening a new session."""
 		self._core = Core(resource_name, id_query, reset, RsNgx._driver_options, options, direct_session)
-		self._core.driver_version = '3.1.0.0048'
+		self._core.driver_version = '3.1.0.0049'
 		self._options = options
 		self._add_all_global_repcaps()
 		self._custom_properties_init()
+		self.utilities.default_instrument_setup()
 		# noinspection PyTypeChecker
-		self._base = CommandsGroup("ROOT", self._core, None)
+		self._cmd_group = CommandsGroup("ROOT", self._core, None)
 		self._selected_channel = int(self._core.io.query_str('INSTrument:NSELect?', True))
 		self._persistent_channel: int = 0
 
@@ -120,7 +121,7 @@ class RsNgx:
 		"""Asserts that the driver version fulfills the minimum required version you have entered.
 		This way you make sure your installed driver is of the entered version or newer."""
 		min_version_list = min_version.split('.')
-		curr_version_list = '3.1.0.0048'.split('.')
+		curr_version_list = '3.1.0.0049'.split('.')
 		count_min = len(min_version_list)
 		count_curr = len(curr_version_list)
 		count = count_min if count_min < count_curr else count_curr
@@ -130,7 +131,7 @@ class RsNgx:
 			if curr > minimum:
 				break
 			if curr < minimum:
-				raise RsInstrException(f"Assertion for minimum RsNgx version failed. Current version: '3.1.0.0048', minimum required version: '{min_version}'")
+				raise RsInstrException(f"Assertion for minimum RsNgx version failed. Current version: '3.1.0.0049', minimum required version: '{min_version}'")
 				
 	@staticmethod
 	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
@@ -165,12 +166,20 @@ class RsNgx:
 		from .CustomFiles.events import Events
 		self.events = Events(self._core)
 
+	@property
+	def log(self):
+		"""log commands group. 7 Sub-classes, 4 commands."""
+		if not hasattr(self, '_log'):
+			from .Implementations.Log import Log
+			self._log = Log(self._core, self._cmd_group)
+		return self._log
+
 	@property
 	def apply(self):
 		"""apply commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_apply'):
 			from .Implementations.Apply import Apply
-			self._apply = Apply(self._core, self._base)
+			self._apply = Apply(self._core, self._cmd_group)
 		return self._apply
 
 	@property
@@ -178,39 +187,23 @@ class RsNgx:
 		"""arbitrary commands group. 6 Sub-classes, 7 commands."""
 		if not hasattr(self, '_arbitrary'):
 			from .Implementations.Arbitrary import Arbitrary
-			self._arbitrary = Arbitrary(self._core, self._base)
+			self._arbitrary = Arbitrary(self._core, self._cmd_group)
 		return self._arbitrary
 
-	@property
-	def data(self):
-		"""data commands group. 2 Sub-classes, 2 commands."""
-		if not hasattr(self, '_data'):
-			from .Implementations.Data import Data
-			self._data = Data(self._core, self._base)
-		return self._data
-
 	@property
 	def fuse(self):
 		"""fuse commands group. 3 Sub-classes, 2 commands."""
 		if not hasattr(self, '_fuse'):
 			from .Implementations.Fuse import Fuse
-			self._fuse = Fuse(self._core, self._base)
+			self._fuse = Fuse(self._core, self._cmd_group)
 		return self._fuse
 
-	@property
-	def instrument(self):
-		"""instrument commands group. 1 Sub-classes, 0 commands."""
-		if not hasattr(self, '_instrument'):
-			from .Implementations.Instrument import Instrument
-			self._instrument = Instrument(self._core, self._base)
-		return self._instrument
-
 	@property
 	def tracking(self):
 		"""tracking commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_tracking'):
 			from .Implementations.Tracking import Tracking
-			self._tracking = Tracking(self._core, self._base)
+			self._tracking = Tracking(self._core, self._cmd_group)
 		return self._tracking
 
 	@property
@@ -218,39 +211,23 @@ class RsNgx:
 		"""calibration commands group. 7 Sub-classes, 7 commands."""
 		if not hasattr(self, '_calibration'):
 			from .Implementations.Calibration import Calibration
-			self._calibration = Calibration(self._core, self._base)
+			self._calibration = Calibration(self._core, self._cmd_group)
 		return self._calibration
 
-	@property
-	def log(self):
-		"""log commands group. 8 Sub-classes, 3 commands."""
-		if not hasattr(self, '_log'):
-			from .Implementations.Log import Log
-			self._log = Log(self._core, self._base)
-		return self._log
-
-	@property
-	def measure(self):
-		"""measure commands group. 2 Sub-classes, 0 commands."""
-		if not hasattr(self, '_measure'):
-			from .Implementations.Measure import Measure
-			self._measure = Measure(self._core, self._base)
-		return self._measure
-
 	@property
 	def output(self):
 		"""output commands group. 6 Sub-classes, 3 commands."""
 		if not hasattr(self, '_output'):
 			from .Implementations.Output import Output
-			self._output = Output(self._core, self._base)
+			self._output = Output(self._core, self._cmd_group)
 		return self._output
 
 	@property
 	def system(self):
-		"""system commands group. 10 Sub-classes, 3 commands."""
+		"""system commands group. 12 Sub-classes, 1 commands."""
 		if not hasattr(self, '_system'):
 			from .Implementations.System import System
-			self._system = System(self._core, self._base)
+			self._system = System(self._core, self._cmd_group)
 		return self._system
 
 	@property
@@ -258,31 +235,31 @@ class RsNgx:
 		"""source commands group. 8 Sub-classes, 0 commands."""
 		if not hasattr(self, '_source'):
 			from .Implementations.Source import Source
-			self._source = Source(self._core, self._base)
+			self._source = Source(self._core, self._cmd_group)
 		return self._source
 
-	@property
-	def status(self):
-		"""status commands group. 2 Sub-classes, 0 commands."""
-		if not hasattr(self, '_status'):
-			from .Implementations.Status import Status
-			self._status = Status(self._core, self._base)
-		return self._status
-
 	@property
 	def trigger(self):
 		"""trigger commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_trigger'):
 			from .Implementations.Trigger import Trigger
-			self._trigger = Trigger(self._core, self._base)
+			self._trigger = Trigger(self._core, self._cmd_group)
 		return self._trigger
 
+	@property
+	def measure(self):
+		"""measure commands group. 2 Sub-classes, 0 commands."""
+		if not hasattr(self, '_measure'):
+			from .Implementations.Measure import Measure
+			self._measure = Measure(self._core, self._cmd_group)
+		return self._measure
+
 	@property
 	def sense(self):
 		"""sense commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_sense'):
 			from .Implementations.Sense import Sense
-			self._sense = Sense(self._core, self._base)
+			self._sense = Sense(self._core, self._cmd_group)
 		return self._sense
 
 	@property
@@ -290,7 +267,7 @@ class RsNgx:
 		"""dio commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_dio'):
 			from .Implementations.Dio import Dio
-			self._dio = Dio(self._core, self._base)
+			self._dio = Dio(self._core, self._cmd_group)
 		return self._dio
 
 	@property
@@ -298,7 +275,7 @@ class RsNgx:
 		"""flog commands group. 1 Sub-classes, 6 commands."""
 		if not hasattr(self, '_flog'):
 			from .Implementations.Flog import Flog
-			self._flog = Flog(self._core, self._base)
+			self._flog = Flog(self._core, self._cmd_group)
 		return self._flog
 
 	@property
@@ -306,7 +283,7 @@ class RsNgx:
 		"""battery commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_battery'):
 			from .Implementations.Battery import Battery
-			self._battery = Battery(self._core, self._base)
+			self._battery = Battery(self._core, self._cmd_group)
 		return self._battery
 
 	@property
@@ -314,7 +291,7 @@ class RsNgx:
 		"""display commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_display'):
 			from .Implementations.Display import Display
-			self._display = Display(self._core, self._base)
+			self._display = Display(self._core, self._cmd_group)
 		return self._display
 
 	@property
@@ -322,7 +299,7 @@ class RsNgx:
 		"""hardCopy commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_hardCopy'):
 			from .Implementations.HardCopy import HardCopy
-			self._hardCopy = HardCopy(self._core, self._base)
+			self._hardCopy = HardCopy(self._core, self._cmd_group)
 		return self._hardCopy
 
 	@property
@@ -330,9 +307,33 @@ class RsNgx:
 		"""interfaces commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_interfaces'):
 			from .Implementations.Interfaces import Interfaces
-			self._interfaces = Interfaces(self._core, self._base)
+			self._interfaces = Interfaces(self._core, self._cmd_group)
 		return self._interfaces
 
+	@property
+	def data(self):
+		"""data commands group. 2 Sub-classes, 2 commands."""
+		if not hasattr(self, '_data'):
+			from .Implementations.Data import Data
+			self._data = Data(self._core, self._cmd_group)
+		return self._data
+
+	@property
+	def instrument(self):
+		"""instrument commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_instrument'):
+			from .Implementations.Instrument import Instrument
+			self._instrument = Instrument(self._core, self._cmd_group)
+		return self._instrument
+
+	@property
+	def status(self):
+		"""status commands group. 2 Sub-classes, 0 commands."""
+		if not hasattr(self, '_status'):
+			from .Implementations.Status import Status
+			self._status = Status(self._core, self._cmd_group)
+		return self._status
+
 	# noinspection PyTypeChecker
 	class Measurement(StructBase):
 		"""Response structure. Fields: \n
@@ -360,6 +361,6 @@ class RsNgx:
 		Calling close() on the new object does not close the original VISA session.
 		This method is similar to calling RsNgx.from_existing_session()"""
 		cloned = RsNgx.from_existing_session(self.get_session_handle(), self._options)
-		self._base.synchronize_repcaps(cloned)
+		self._cmd_group.synchronize_repcaps(cloned)
 		
 		return cloned
