@@ -15,6 +15,15 @@ class ArbTrigMode(Enum):
 	SINGle = 1
 
 
+# noinspection SpellCheckingInspection
+class CalibrationType(Enum):
+	"""4 Members, CURR ... VOLT"""
+	CURR = 0
+	IMP = 1
+	NCUR = 2
+	VOLT = 3
+
+
 # noinspection SpellCheckingInspection
 class DefaultStep(Enum):
 	"""2 Members, DEF ... DEFault"""
